!function(){try{var e="undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:{};e.SENTRY_RELEASE={id:"768c393028531b48d077404b24343b320adb8107"};var n=(new e.Error).stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="73c0bcc6-de5c-4b05-a925-982eba26fb3d",e._sentryDebugIdIdentifier="sentry-dbid-73c0bcc6-de5c-4b05-a925-982eba26fb3d")}catch(e){}}(),self.onmessage=function(e){const{collection:n,sortBy:t}=e.data,i={"alpha-asc":(e,n)=>String(e.label).localeCompare(String(n.label),void 0,{sensitivity:"accent",ignorePunctuation:!0,numeric:!0}),"alpha-desc":(e,n)=>String(n.label).localeCompare(String(e.label),void 0,{sensitivity:"accent",ignorePunctuation:!0,numeric:!0}),"num-asc":(e,n)=>String(e.pill_raw||e.pill||e.actualCount||e.count||0).localeCompare(String(n.pill_raw||n.pill||n.actualCount||n.count||0),void 0,{sensitivity:"accent",ignorePunctuation:!0,numeric:!0}),"num-desc":(e,n)=>String(n.pill_raw||n.pill||n.actualCount||n.count||0).localeCompare(String(e.pill_raw||e.pill||e.actualCount||e.count||0),void 0,{sensitivity:"accent",ignorePunctuation:!0,numeric:!0})},a=i[t]||i["alpha-asc"],l=n.slice().sort(a);self.postMessage(l)};