!function(){try{var e="undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:{};e.SENTRY_RELEASE={id:"768c393028531b48d077404b24343b320adb8107"};var d=(new e.Error).stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="ad3ab672-7ef2-4b0b-ac07-67c73d500da3",e._sentryDebugIdIdentifier="sentry-dbid-ad3ab672-7ef2-4b0b-ac07-67c73d500da3")}catch(e){}}(),(globalThis.webpackChunkcloud_frontend=globalThis.webpackChunkcloud_frontend||[]).push([[3808],{43808(e,d,n){n.r(d),n.d(d,{default:()=>s});var t=n(5981),a=n(44245),b=n(74090),o=n(75250),i=n(99094),r=n(74848);const s=()=>{const{reportId:e}=(0,t.g)(),d=(0,o.A)({id:e});return(0,a.ZB)({title:d,id:e,destination:e,type:i.p9}),(0,r.jsx)(b.A,{})}}}]);