!function(){try{var d="undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:{};d.SENTRY_RELEASE={id:"768c393028531b48d077404b24343b320adb8107"};var e=(new d.Error).stack;e&&(d._sentryDebugIds=d._sentryDebugIds||{},d._sentryDebugIds[e]="85a01121-26d0-4dc0-acc1-8c450ab37238",d._sentryDebugIdIdentifier="sentry-dbid-85a01121-26d0-4dc0-acc1-8c450ab37238")}catch(d){}}(),(globalThis.webpackChunkcloud_frontend=globalThis.webpackChunkcloud_frontend||[]).push([[4306],{95297(d,e,a){a.r(e),a.d(e,{DashboardContent:()=>A,default:()=>m});a(33110);var o=a(96540),t=a(5981),s=a(96243);const r=d=>{const{dashboardSlug:e=d}=(0,t.g)(),a=(0,s.Xv)(),r=(0,s.Tf)();return(0,o.useEffect)(()=>{r!==e&&a(e)},[r,e]),(0,o.useEffect)(()=>()=>a(null),[]),e};a.dn(r);var n=a(93933),i=a(24609),l=a(19186),b=a(41579),u=a(67294),c=a(96957),f=a(44245),g=a(45706),h=a(1623),p=a(68477),y=a(12407),v=a(60908),I=a(74848);const A=d=>{let{id:e}=d;const a=(0,i.vt)(),o=(0,i.bq)(),t=(0,l.ID)(),s=(0,l.QW)(),r=(0,c.oj)("state"),n=(0,g.A)(e,{spaceId:a,spaceSlug:o,roomId:t,roomSlug:s});return n?(0,I.jsx)(h.A,{}):(0,I.jsx)(v.Ay,{feature:"Dashboard",dashboardId:e,children:"notAvailable"===r?(0,I.jsx)(y.A,{flavour:"dashboard"}):(0,I.jsx)(p.A,{id:e},JSON.stringify({id:e,loading:n}))})},m=(0,o.memo)(d=>{let{customDashboardId:e}=d;(0,b.A)(),r(e),(0,n.z1)(e);const a=(0,c.zi)(e),o=(0,c.oj)("slug");(0,f.ZB)({title:o,id:a,destination:o,type:"dashboards",droppable:!0,droppableProps:{dashboardId:a,dropArea:!0},tooltip:{title:o,description:"Custom dashboard with personalized visualizations and metrics tailored to your monitoring requirements."}});const t=(0,u.RQ)();return(0,I.jsx)(A,{id:t?a:null})})},1623(d,e,a){a.d(e,{A:()=>s});var o=a(63474),t=a(74848);const s=()=>(0,t.jsx)(o.O2,{"data-testid":"dashboardLoading"})},47154(d,e,a){var o=a(66118);o.t1.register(...o.$L)}}]);