!function(){try{var d="undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:{};d.SENTRY_RELEASE={id:"768c393028531b48d077404b24343b320adb8107"};var e=(new d.Error).stack;e&&(d._sentryDebugIds=d._sentryDebugIds||{},d._sentryDebugIds[e]="f171587d-c4af-4b52-950a-223253a55700",d._sentryDebugIdIdentifier="sentry-dbid-f171587d-c4af-4b52-950a-223253a55700")}catch(d){}}(),(globalThis.webpackChunkcloud_frontend=globalThis.webpackChunkcloud_frontend||[]).push([[6333],{96333(d,e,o){o.r(e),o.d(e,{default:()=>p});var n=o(96540),s=o(5981),a=o(32977),t=o(29022),l=o(79748),r=o(61841),i=o(81391),c=o(19186),b=o(37617),f=o(99728),u=o(82213),h=o(25962),g=o(74848);const p=()=>{const[d,e]=(0,r.Ay)(),{path:o}=(0,b.A)(),p=(0,i.n)("id"),w=(0,c.wz)(p,"loaded"),y=(0,c.wz)(p,"nodeCount"),A=(0,s.Zp)();(0,n.useEffect)(()=>{w&&0===y&&A(o,{replace:!0})},[w,y,o,A]);const m=(0,f.JT)("node:Create"),x=(0,c.XA)(),T=(0,c.pr)(),N=x?.loaded?x:T,_=N?.id,[E,{onAddNodes:j,selectedNodes:k}]=(0,h.A)(_);return w?(0,g.jsxs)(t.A,{title:"Empty room",children:[(0,g.jsx)(a.Text,{children:"This room has no nodes."}),m&&(0,g.jsx)(a.Flex,{column:!0,gap:8,children:(0,g.jsxs)(a.Text,{children:["Go to"," ",(0,g.jsx)(l.A,{as:s.N_,to:`/spaces/${d}/settings/rooms/${e}?tab=nodes`,children:"room settings"})," ","and add some nodes."]})}),!N.untouchable&&(0,g.jsx)(u.A,{"data-testid":"addRoomModal-availableNodes",overflow:"hidden",showHeader:!0,roomId:_,...E,onAddNodes:j,canAddNodes:!!k.length,addNodesGA:"add-war-room-modal::click-add-node::global-view"})]}):null}}}]);