!function(){try{var e="undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:{};e.SENTRY_RELEASE={id:"768c393028531b48d077404b24343b320adb8107"};var n=(new e.Error).stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="8808de50-f71b-462b-8545-5977ae684ede",e._sentryDebugIdIdentifier="sentry-dbid-8808de50-f71b-462b-8545-5977ae684ede")}catch(e){}}(),(globalThis.webpackChunkcloud_frontend=globalThis.webpackChunkcloud_frontend||[]).push([[7543],{77543(e,n,d){d.r(n),d.d(n,{default:()=>a});var t=d(96540),l=d(32977),r=d(23947),u=d(3319),o=d(62718),s=d(74848);const a=()=>{const{sendLog:e}=(0,u.A)(),n=(0,r.So)(),d=(0,t.useRef)(!1),a=(0,t.useCallback)(()=>{d.current||(d.current=!0,e({feature:"SignUpThankYou"}).finally(()=>{n()}))},[n]);return(0,t.useEffect)(()=>{let e=!0,n=setTimeout(()=>{e&&a()},1e3);return()=>{e=!1,n&&(clearTimeout(n),n=null)}},[]),(0,s.jsx)(l.Flex,{width:"100",height:"100vh",children:(0,s.jsx)(o.yj,{})})}}}]);