!function(){try{var e="undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:{};e.SENTRY_RELEASE={id:"768c393028531b48d077404b24343b320adb8107"};var n=(new e.Error).stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="81f90512-51f1-422e-912e-68b18cfb492c",e._sentryDebugIdIdentifier="sentry-dbid-81f90512-51f1-422e-912e-68b18cfb492c")}catch(e){}}(),(globalThis.webpackChunkcloud_frontend=globalThis.webpackChunkcloud_frontend||[]).push([[35],{70035(e,n,l){l.r(n),l.d(n,{default:()=>b});var d=l(46587),s=l(32977),o=l(18739),t=l(24155),i=l(74848);const r=()=>{const{loaded:e,value:n}=(0,o.JN)(),l=[n.class,...n.trialEndsAt?["(Trial)"]:[]].join(" ");return e?e&&l.length?(0,i.jsx)(s.Flex,{children:(0,i.jsx)(s.Pill,{children:l})}):null:(0,i.jsx)(t.A,{height:"22px"})},b=()=>(0,d.uW)("isAnonymous")?null:(0,i.jsx)(r,{})}}]);