!function(){try{var e="undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:{};e.SENTRY_RELEASE={id:"768c393028531b48d077404b24343b320adb8107"};var r=(new e.Error).stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="67b72329-0a99-4ea1-9bb5-d5f768c16e8e",e._sentryDebugIdIdentifier="sentry-dbid-67b72329-0a99-4ea1-9bb5-d5f768c16e8e")}catch(e){}}(),(()=>{var e={},r={};function n(t){var o=r[t];if(void 0!==o)return o.exports;var a=r[t]={exports:{}};return e[t](a,a.exports,n),a.exports}n.m=e,n.d=(e,r)=>{for(var t in r)n.o(r,t)&&!n.o(e,t)&&Object.defineProperty(e,t,{enumerable:!0,get:r[t]})},n.f={},n.e=e=>Promise.all(Object.keys(n.f).reduce((r,t)=>(n.f[t](e,r),r),[])),n.u=e=>e+".c56a31ff1405255b40b4.chunk.js",n.miniCssF=e=>{},n.o=(e,r)=>Object.prototype.hasOwnProperty.call(e,r),n.r=e=>{"undefined"!==typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(e,"__esModule",{value:!0})},n.p="/",(()=>{n.b=self.location+"";var e={9995:1};n.f.i=(r,t)=>{e[r]||importScripts(n.p+n.u(r))};var r=globalThis.webpackChunkcloud_frontend=globalThis.webpackChunkcloud_frontend||[],t=r.push.bind(r);r.push=r=>{var[o,a,s]=r;for(var d in a)n.o(a,d)&&(n.m[d]=a[d]);for(s&&s(n);o.length;)e[o.pop()]=1;t(r)}})();let t=null;const o=async(e,r)=>{const o=performance.now(),a=await(t||(t=n.e(7080).then(n.bind(n,74699)).then(async e=>(await e.default(),e)).catch(e=>{throw t=null,e})),t),s=performance.now(),d=r.edges,i=new Array(d.length/2);for(let n=0,t=0;n<d.length;n+=2,t+=1)i[t]=[d[n],d[n+1]];const l=Array.from(r.nodes),f=Array.from(r.masses),c=Array.from(r.weights),u=performance.now(),b=a.force({name:0,dimensions:2,chunk_size:256,nodes:l,edges:i,masses:f,weights:c,iterations:100,min_movement:.5,distance_threshold_mode:0,center:r.center,ka:1,kg:5,kr:10,speed:.1,prevent_overlapping:!1,node_radius:10,kr_prime:10,strong_gravity:!1,lin_log:!1,dissuade_hubs:!1,edge_strength:0,link_distance:0,node_strength:0,coulomb_dis_scale:0,factor:0,interval:0,damping:0,max_speed:0,max_distance:100}),p=performance.now(),g=new Float32Array(b.length);for(let n=0;n<b.length;n+=1)g[n]=b[n];self.postMessage({id:e,result:g,wasmMs:p-u,initMs:s-o,totalMs:p-o},[g.buffer])};self.addEventListener("message",async e=>{const r=e.data||{},{id:n}=r;try{await o(n,r)}catch(t){try{self.postMessage({id:n,error:t?.message||"layout worker failed"})}catch{}}})})();