!function(){try{var e="undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:{};e.SENTRY_RELEASE={id:"768c393028531b48d077404b24343b320adb8107"};var o=(new e.Error).stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="5128aa66-f353-422c-9e35-4368a09c7e3b",e._sentryDebugIdIdentifier="sentry-dbid-5128aa66-f353-422c-9e35-4368a09c7e3b")}catch(e){}}(),(globalThis.webpackChunkcloud_frontend=globalThis.webpackChunkcloud_frontend||[]).push([[8723],{78723(e,o,t){t.r(o),t.d(o,{default:()=>c});t(98992),t(54520),t(81454),t(25509),t(65223),t(60321),t(41927),t(11632),t(64377),t(66771),t(12516),t(68931),t(52514),t(35694),t(52774),t(49536),t(21926),t(94483),t(16215);var l=t(96540),n=t(32977),s=t(85660),a=t(26924),d=t(76815),i=t(65131),r=t(74848);const c=(0,l.memo)(e=>{let{topologyGraph:o,topologyActorRows:t,topologyMeta:c,topologyEvidence:g,topologyTables:u,topologyOverlays:p,presentation:y,filterKey:f}=e;const b=(0,l.useMemo)(()=>(0,i.yH)(c),[c])||y,h=(0,l.useMemo)(()=>(0,i.XG)(c?.portBulletsByActor),[c]),[k,m]=(0,l.useState)(null),[x,I]=(0,l.useState)(""),[v,w]=(0,l.useState)(""),[L,{height:C}]=(0,s.A)(),M=Math.max(300,C-8),T=(0,l.useCallback)(e=>{I(e.id),w(""),m(e.id)},[]),E=(0,l.useCallback)(e=>{w(e.id),I("")},[]),S=(0,l.useCallback)(()=>m(null),[]),{nodes:_=[],links:j=[],aggregatedLinks:A}=o||{},N=(0,l.useMemo)(()=>(0,i.cl)({nodes:_,topologyTables:u,presentation:b}),[_,u,b]),D=(0,l.useMemo)(()=>new Set((t||[]).map(e=>e.id)),[t]),O=(0,l.useMemo)(()=>t?N.filter(e=>D.has(e.id)):N,[N,D,t]),R=(0,l.useMemo)(()=>t?j.filter(e=>D.has(e.source)&&D.has(e.target)):j,[j,D,t]);return O.length?(0,r.jsxs)(n.Flex,{ref:L,flex:!0,column:!0,overflow:"hidden",children:[(0,r.jsx)(a.A,{nodes:O,links:R,portStateLinks:j,selectedNodeId:x,selectedLinkId:v,height:M,filterKey:f,presentation:b,portInventoryOverride:h,onNodeClick:T,onLinkClick:E}),!!k&&(0,r.jsx)(d.A,{actorId:k,graphNodes:N,graphLinks:j,aggregatedLinks:A,allLinks:j,presentation:b,topologyEvidence:g,topologyTables:u,topologyOverlays:p,topologyMeta:c,selectedLinkId:v,onClose:S})]}):(0,r.jsx)(n.Flex,{flex:!0,alignItems:"center",justifyContent:"center",children:(0,r.jsx)(n.Text,{color:"textLite",children:"No topology data"})})})}}]);