!function(){try{var e="undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:{};e.SENTRY_RELEASE={id:"768c393028531b48d077404b24343b320adb8107"};var r=(new e.Error).stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="bc85992e-a145-4d63-9925-0cc8dca2c086",e._sentryDebugIdIdentifier="sentry-dbid-bc85992e-a145-4d63-9925-0cc8dca2c086")}catch(e){}}(),(globalThis.webpackChunkcloud_frontend=globalThis.webpackChunkcloud_frontend||[]).push([[8212],{98212(e,r,t){t.r(r),t.d(r,{default:()=>d});var n=t(96540),o=t(41514),s=t(32977),a=t(74848);class c extends n.Component{constructor(e){super(e),this.state={hasError:!1,error:null}}static getDerivedStateFromError(e){return{hasError:!0,error:e}}componentDidCatch(e,r){(0,o.H)("geomap-error",{error:e.message,stack:r.componentStack})}render(){return this.state.hasError?(0,a.jsxs)(s.Flex,{column:!0,alignItems:"center",justifyContent:"center",height:"100%",gap:4,padding:[8],children:[(0,a.jsx)(s.Icon,{name:"alert_triangle",size:"large",color:"error"}),(0,a.jsx)(s.Text,{strong:!0,children:"Map failed to load"}),(0,a.jsx)(s.Text,{color:"textLite",textAlign:"center",width:{max:100},children:this.state.error?.message||"An error occurred while loading the map. Please check your network connection and try again."}),(0,a.jsx)(s.Button,{flavour:"borderless",onClick:()=>this.setState({hasError:!1,error:null}),children:"Retry"})]}):this.props.children}}const d=c}}]);