!function(){try{var e="undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:{};e.SENTRY_RELEASE={id:"768c393028531b48d077404b24343b320adb8107"};var d=(new e.Error).stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="b9ad7b3d-d4b8-449b-9104-ff4116c27e60",e._sentryDebugIdIdentifier="sentry-dbid-b9ad7b3d-d4b8-449b-9104-ff4116c27e60")}catch(e){}}(),(globalThis.webpackChunkcloud_frontend=globalThis.webpackChunkcloud_frontend||[]).push([[891],{40891(e,d,n){n.r(d),n.d(d,{default:()=>a});var b=n(98591),o=n(42660),s=n(83864),t=n(74848);const a=()=>{const[e,,,d]=(0,b.A)("manageInvitations");return(0,t.jsx)(o.A,{children:e&&(0,t.jsx)(s.d,{onClose:d})})}}}]);