!function(){try{var e="undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:{};e.SENTRY_RELEASE={id:"768c393028531b48d077404b24343b320adb8107"};var a=(new e.Error).stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="f95c0509-8ee4-4cbd-b849-0b7cdfa9d808",e._sentryDebugIdIdentifier="sentry-dbid-f95c0509-8ee4-4cbd-b849-0b7cdfa9d808")}catch(e){}}(),(globalThis.webpackChunkcloud_frontend=globalThis.webpackChunkcloud_frontend||[]).push([[8399],{80590(e,a,n){n.d(a,{A:()=>s});var t=n(96540),i=n(3319),c=n(74848);const s=e=>a=>{let{callback:n,feature:s,isStart:d,isSuccess:l,isFailure:o,eventReason:r,payload:u={},...b}=a;const{sendLog:h,isReady:g}=(0,i.A)(),f=(0,t.useCallback)(e=>{const a=b[n],t={...s?{feature:s}:{},...void 0!==d?{isStart:d}:{},...void 0!==l?{isSuccess:l}:{},...void 0!==o?{isFailure:o}:{},...r?{eventReason:r}:{},...u,...b["data-ga"]?{dataGa:b["data-ga"]}:{},...b.dataGa?{dataGa:b.dataGa}:{},...b["data-track"]?{dataTrack:b["data-track"]}:{},...b.label?{label:b.label}:{}};"function"===typeof a&&a(e),h(t,!0)},[n,h,g,u,b]),k=(0,t.useMemo)(()=>({...b,[n]:f}),[b,n,f]);return(0,c.jsx)(e,{...k})}},94404(e,a,n){n.d(a,{A:()=>s});var t=n(80590),i=n(81691),c=n(74848);const s=e=>a=>{let{payload:n={},...s}=a;const d=(0,t.A)(e);return(0,c.jsx)(d,{...s,callback:"onClick",payload:{...n,action:i.o1.buttonClicked}})}},8399(e,a,n){n.r(a),n.d(a,{MagicLinkSent:()=>p,default:()=>y});var t=n(96540),i=n(882),c=n(5981),s=n(32977),d=n(42660),l=n(27606),o=n(87875),r=n(3575),u=n(23947),b=n(10444),h=n(60908),g=n(94404),f=n(74848);const k=(0,i.default)(s.Text).attrs({role:"button"}).withConfig({displayName:"magicLinkSent__ButtonText",componentId:"sc-ua6kmo-0"})(["cursor:pointer;"]),m=(0,g.A)(k),p=()=>{const{searchParams:e}=new URL(window.location.href),a=e?.get("email"),{search:n,state:i={}}=(0,c.zy)(),{email:d}=i||{},g=a||d,k=window.location.hash,p=(0,u.Js)(),y=(0,b.J)(),x=(0,t.useCallback)(()=>{const e=encodeURIComponent((0,r.V)(`/sign-in${n}`,k)),a=encodeURIComponent((0,r.V)(`/sign-up/verify${n}`,k));p({email:g,redirectURI:e,registerURI:a,resend:!0})},[g]);return(0,f.jsx)(h.Ay,{feature:"MagicLinkSent",email:g,children:(0,f.jsx)(l.A,{"data-testid":"magicLinkSent",isScreenSmall:y,children:(0,f.jsxs)(s.Flex,{column:!0,gap:4,children:[(0,f.jsx)(o.D7,{children:"Check your email!"}),(0,f.jsxs)(s.Flex,{column:!0,padding:[0,0,8,0],gap:8,justifyContent:"between",alignItems:"center",children:[(0,f.jsxs)(s.Flex,{column:!0,gap:1,alignItems:"center",children:[(0,f.jsxs)(o.D7,{children:["We have sent an email to ",(0,f.jsx)(o.D7,{children:!!g&&g}),"."]}),(0,f.jsx)(o.D7,{children:"Please find this email (check your spam folder too) and click the button there to continue."})]}),(0,f.jsxs)(s.Text,{color:"bright",children:["Didn't receive it?"," ",(0,f.jsx)(m,{onClick:x,color:"primary","data-ga":"magicLikSent::click-resent::check-email-view",children:"Click here to resend it."})]})]})]})})})},y=(0,d.g)(p,"dark")}}]);